# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import functions_type_mapping
missing = Sentinel("Missing")


class FunctionsManagementClient(object):
    """
    API for the Functions service.
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20181201',
            'service_endpoint_template': 'https://functions.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        self.base_client = BaseClient("functions_management", config, signer, functions_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')

    def change_application_compartment(self, application_id, change_application_compartment_details, **kwargs):
        """
        Moves an application into a different compartment within the same tenancy.
        For information about moving resources between compartments, see `Moving Resources Between Compartments`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes


        :param str application_id: (required)
            The `OCID`__ of this application.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.functions.models.ChangeApplicationCompartmentDetails change_application_compartment_details: (required)
            Properties to change the compartment of an application.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource, set the `if-match`
            parameter to the value of the etag from a previous GET or POST response for that resource.  The resource
            will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/change_application_compartment.py.html>`__ to see an example of how to use change_application_compartment API.
        """
        resource_path = "/applications/{applicationId}/actions/changeCompartment"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "change_application_compartment got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "applicationId": application_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_application_compartment_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_application_compartment_details)

    def create_application(self, create_application_details, **kwargs):
        """
        Creates a new application.


        :param oci.functions.models.CreateApplicationDetails create_application_details: (required)
            Specification of the application to create

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.functions.models.Application`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/create_application.py.html>`__ to see an example of how to use create_application API.
        """
        resource_path = "/applications"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_application got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_application_details,
                response_type="Application")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_application_details,
                response_type="Application")

    def create_function(self, create_function_details, **kwargs):
        """
        Creates a new function.


        :param oci.functions.models.CreateFunctionDetails create_function_details: (required)
            Specification of the function to create

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.functions.models.Function`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/create_function.py.html>`__ to see an example of how to use create_function API.
        """
        resource_path = "/functions"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_function got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_function_details,
                response_type="Function")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_function_details,
                response_type="Function")

    def delete_application(self, application_id, **kwargs):
        """
        Deletes an application.


        :param str application_id: (required)
            The `OCID`__ of this application.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource, set the `if-match`
            parameter to the value of the etag from a previous GET or POST response for that resource.  The resource
            will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/delete_application.py.html>`__ to see an example of how to use delete_application API.
        """
        resource_path = "/applications/{applicationId}"
        method = "DELETE"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_application got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "applicationId": application_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def delete_function(self, function_id, **kwargs):
        """
        Deletes a function.


        :param str function_id: (required)
            The `OCID`__ of this function.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource, set the `if-match`
            parameter to the value of the etag from a previous GET or POST response for that resource.  The resource
            will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/delete_function.py.html>`__ to see an example of how to use delete_function API.
        """
        resource_path = "/functions/{functionId}"
        method = "DELETE"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_function got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "functionId": function_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def get_application(self, application_id, **kwargs):
        """
        Retrieves an application.


        :param str application_id: (required)
            The `OCID`__ of this application.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.functions.models.Application`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/get_application.py.html>`__ to see an example of how to use get_application API.
        """
        resource_path = "/applications/{applicationId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_application got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "applicationId": application_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Application")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Application")

    def get_function(self, function_id, **kwargs):
        """
        Retrieves a function.


        :param str function_id: (required)
            The `OCID`__ of this function.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.functions.models.Function`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/get_function.py.html>`__ to see an example of how to use get_function API.
        """
        resource_path = "/functions/{functionId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_function got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "functionId": function_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Function")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Function")

    def list_applications(self, compartment_id, **kwargs):
        """
        Lists applications for a compartment.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment to which this resource belongs.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param int limit: (optional)
            The maximum number of items to return. 1 is the minimum, 50 is the maximum.

            Default: 10

        :param str page: (optional)
            The pagination token for a list query returned by a previous operation

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param str lifecycle_state: (optional)
            A filter to return only applications that match the lifecycle state in this parameter.
            Example: `Creating`

            Allowed values are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"

        :param str display_name: (optional)
            A filter to return only applications with display names that match the display name string. Matching is exact.

        :param str id: (optional)
            A filter to return only applications with the specified OCID.

        :param str sort_order: (optional)
            Specifies sort order.

            * **ASC:** Ascending sort order.
            * **DESC:** Descending sort order.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            Specifies the attribute with which to sort the rules.

            Default: `displayName`

            * **timeCreated:** Sorts by timeCreated.
            * **displayName:** Sorts by displayName.
            * **id:** Sorts by id.

            Allowed values are: "timeCreated", "id", "displayName"

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type list of :class:`~oci.functions.models.ApplicationSummary`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/list_applications.py.html>`__ to see an example of how to use list_applications API.
        """
        resource_path = "/applications"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "limit",
            "page",
            "opc_request_id",
            "lifecycle_state",
            "display_name",
            "id",
            "sort_order",
            "sort_by"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_applications got unknown kwargs: {!r}".format(extra_kwargs))

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "id", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        query_params = {
            "compartmentId": compartment_id,
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "lifecycleState": kwargs.get("lifecycle_state", missing),
            "displayName": kwargs.get("display_name", missing),
            "id": kwargs.get("id", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="list[ApplicationSummary]")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="list[ApplicationSummary]")

    def list_functions(self, application_id, **kwargs):
        """
        Lists functions for an application.


        :param str application_id: (required)
            The `OCID`__ of the application to which this function belongs.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param int limit: (optional)
            The maximum number of items to return. 1 is the minimum, 50 is the maximum.

            Default: 10

        :param str page: (optional)
            The pagination token for a list query returned by a previous operation

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param str lifecycle_state: (optional)
            A filter to return only functions that match the lifecycle state in this parameter.
            Example: `Creating`

            Allowed values are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"

        :param str display_name: (optional)
            A filter to return only functions with display names that match the display name string. Matching is exact.

        :param str id: (optional)
            A filter to return only functions with the specified OCID.

        :param str sort_order: (optional)
            Specifies sort order.

            * **ASC:** Ascending sort order.
            * **DESC:** Descending sort order.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            Specifies the attribute with which to sort the rules.

            Default: `displayName`

            * **timeCreated:** Sorts by timeCreated.
            * **displayName:** Sorts by displayName.
            * **id:** Sorts by id.

            Allowed values are: "timeCreated", "id", "displayName"

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type list of :class:`~oci.functions.models.FunctionSummary`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/list_functions.py.html>`__ to see an example of how to use list_functions API.
        """
        resource_path = "/functions"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "limit",
            "page",
            "opc_request_id",
            "lifecycle_state",
            "display_name",
            "id",
            "sort_order",
            "sort_by"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_functions got unknown kwargs: {!r}".format(extra_kwargs))

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "id", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        query_params = {
            "applicationId": application_id,
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "lifecycleState": kwargs.get("lifecycle_state", missing),
            "displayName": kwargs.get("display_name", missing),
            "id": kwargs.get("id", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="list[FunctionSummary]")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="list[FunctionSummary]")

    def update_application(self, application_id, update_application_details, **kwargs):
        """
        Modifies an application


        :param str application_id: (required)
            The `OCID`__ of this application.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.functions.models.UpdateApplicationDetails update_application_details: (required)
            The new application spec to apply

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource, set the `if-match`
            parameter to the value of the etag from a previous GET or POST response for that resource.  The resource
            will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.functions.models.Application`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/update_application.py.html>`__ to see an example of how to use update_application API.
        """
        resource_path = "/applications/{applicationId}"
        method = "PUT"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_application got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "applicationId": application_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_application_details,
                response_type="Application")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_application_details,
                response_type="Application")

    def update_function(self, function_id, update_function_details, **kwargs):
        """
        Modifies a function


        :param str function_id: (required)
            The `OCID`__ of this function.

            __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm

        :param oci.functions.models.UpdateFunctionDetails update_function_details: (required)
            The new function spec to apply

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource, set the `if-match`
            parameter to the value of the etag from a previous GET or POST response for that resource.  The resource
            will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
            particular request, please provide the request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.functions.models.Function`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/functions/update_function.py.html>`__ to see an example of how to use update_function API.
        """
        resource_path = "/functions/{functionId}"
        method = "PUT"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_function got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "functionId": function_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_function_details,
                response_type="Function")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_function_details,
                response_type="Function")



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceAgentCommandSourceDetails(object):
    """
    The source of the command.
    """

    #: A constant which can be used with the source_type property of a InstanceAgentCommandSourceDetails.
    #: This constant has a value of "TEXT"
    SOURCE_TYPE_TEXT = "TEXT"

    #: A constant which can be used with the source_type property of a InstanceAgentCommandSourceDetails.
    #: This constant has a value of "OBJECT_STORAGE_URI"
    SOURCE_TYPE_OBJECT_STORAGE_URI = "OBJECT_STORAGE_URI"

    #: A constant which can be used with the source_type property of a InstanceAgentCommandSourceDetails.
    #: This constant has a value of "OBJECT_STORAGE_TUPLE"
    SOURCE_TYPE_OBJECT_STORAGE_TUPLE = "OBJECT_STORAGE_TUPLE"

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceAgentCommandSourceDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.compute_instance_agent.models.InstanceAgentCommandSourceViaObjectStorageTupleDetails`
        * :class:`~oci.compute_instance_agent.models.InstanceAgentCommandSourceViaObjectStorageUriDetails`
        * :class:`~oci.compute_instance_agent.models.InstanceAgentCommandSourceViaTextDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this InstanceAgentCommandSourceDetails.
            Allowed values for this property are: "TEXT", "OBJECT_STORAGE_URI", "OBJECT_STORAGE_TUPLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source_type: str

        """
        self.swagger_types = {
            'source_type': 'str'
        }

        self.attribute_map = {
            'source_type': 'sourceType'
        }

        self._source_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['sourceType']

        if type == 'OBJECT_STORAGE_TUPLE':
            return 'InstanceAgentCommandSourceViaObjectStorageTupleDetails'

        if type == 'OBJECT_STORAGE_URI':
            return 'InstanceAgentCommandSourceViaObjectStorageUriDetails'

        if type == 'TEXT':
            return 'InstanceAgentCommandSourceViaTextDetails'
        else:
            return 'InstanceAgentCommandSourceDetails'

    @property
    def source_type(self):
        """
        **[Required]** Gets the source_type of this InstanceAgentCommandSourceDetails.
        The source type for the command. The following values are supported:

        - `TEXT` - uses a plain text command that is specified inline with the request.
        - `OBJECT_STORAGE_URI` - imports a command from an Object Storage URL.
        - `OBJECT_STORAGE_TUPLE` - imports a command from an Object Storage bucket.

        For background information about Object Storage buckets and URLs, see
        `Overview of Object Storage`__.

        __ https://docs.cloud.oracle.com/Content/Object/Concepts/objectstorageoverview.htm

        Allowed values for this property are: "TEXT", "OBJECT_STORAGE_URI", "OBJECT_STORAGE_TUPLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source_type of this InstanceAgentCommandSourceDetails.
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """
        Sets the source_type of this InstanceAgentCommandSourceDetails.
        The source type for the command. The following values are supported:

        - `TEXT` - uses a plain text command that is specified inline with the request.
        - `OBJECT_STORAGE_URI` - imports a command from an Object Storage URL.
        - `OBJECT_STORAGE_TUPLE` - imports a command from an Object Storage bucket.

        For background information about Object Storage buckets and URLs, see
        `Overview of Object Storage`__.

        __ https://docs.cloud.oracle.com/Content/Object/Concepts/objectstorageoverview.htm


        :param source_type: The source_type of this InstanceAgentCommandSourceDetails.
        :type: str
        """
        allowed_values = ["TEXT", "OBJECT_STORAGE_URI", "OBJECT_STORAGE_TUPLE"]
        if not value_allowed_none_or_none_sentinel(source_type, allowed_values):
            source_type = 'UNKNOWN_ENUM_VALUE'
        self._source_type = source_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ErrorDetails(object):
    """
    Error Information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ErrorDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param code:
            The value to assign to the code property of this ErrorDetails.
        :type code: str

        :param message:
            The value to assign to the message property of this ErrorDetails.
        :type message: str

        """
        self.swagger_types = {
            'code': 'str',
            'message': 'str'
        }

        self.attribute_map = {
            'code': 'code',
            'message': 'message'
        }

        self._code = None
        self._message = None

    @property
    def code(self):
        """
        **[Required]** Gets the code of this ErrorDetails.
        A short error code that defines the error, meant for programmatic parsing.


        :return: The code of this ErrorDetails.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this ErrorDetails.
        A short error code that defines the error, meant for programmatic parsing.


        :param code: The code of this ErrorDetails.
        :type: str
        """
        self._code = code

    @property
    def message(self):
        """
        **[Required]** Gets the message of this ErrorDetails.
        A human-readable error string.


        :return: The message of this ErrorDetails.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ErrorDetails.
        A human-readable error string.


        :param message: The message of this ErrorDetails.
        :type: str
        """
        self._message = message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RequestSummarizedJreUsageDetails(object):
    """
    Parameters for filtering Java Runtime Usages.
    """

    #: A constant which can be used with the sort_order property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "ASC"
    SORT_ORDER_ASC = "ASC"

    #: A constant which can be used with the sort_order property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "DESC"
    SORT_ORDER_DESC = "DESC"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "distribution"
    SORT_BY_DISTRIBUTION = "distribution"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "timeFirstSeen"
    SORT_BY_TIME_FIRST_SEEN = "timeFirstSeen"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "timeLastSeen"
    SORT_BY_TIME_LAST_SEEN = "timeLastSeen"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "vendor"
    SORT_BY_VENDOR = "vendor"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "version"
    SORT_BY_VERSION = "version"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "approximateInstallationCount"
    SORT_BY_APPROXIMATE_INSTALLATION_COUNT = "approximateInstallationCount"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "approximateApplicationCount"
    SORT_BY_APPROXIMATE_APPLICATION_COUNT = "approximateApplicationCount"

    #: A constant which can be used with the sort_by property of a RequestSummarizedJreUsageDetails.
    #: This constant has a value of "approximateManagedInstanceCount"
    SORT_BY_APPROXIMATE_MANAGED_INSTANCE_COUNT = "approximateManagedInstanceCount"

    def __init__(self, **kwargs):
        """
        Initializes a new RequestSummarizedJreUsageDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_start:
            The value to assign to the time_start property of this RequestSummarizedJreUsageDetails.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this RequestSummarizedJreUsageDetails.
        :type time_end: datetime

        :param jre_vendor:
            The value to assign to the jre_vendor property of this RequestSummarizedJreUsageDetails.
        :type jre_vendor: str

        :param jre_distribution:
            The value to assign to the jre_distribution property of this RequestSummarizedJreUsageDetails.
        :type jre_distribution: str

        :param jre_version:
            The value to assign to the jre_version property of this RequestSummarizedJreUsageDetails.
        :type jre_version: str

        :param application_id:
            The value to assign to the application_id property of this RequestSummarizedJreUsageDetails.
        :type application_id: str

        :param managed_instance_id:
            The value to assign to the managed_instance_id property of this RequestSummarizedJreUsageDetails.
        :type managed_instance_id: str

        :param sort_order:
            The value to assign to the sort_order property of this RequestSummarizedJreUsageDetails.
            Allowed values for this property are: "ASC", "DESC"
        :type sort_order: str

        :param sort_by:
            The value to assign to the sort_by property of this RequestSummarizedJreUsageDetails.
            Allowed values for this property are: "distribution", "timeFirstSeen", "timeLastSeen", "vendor", "version", "approximateInstallationCount", "approximateApplicationCount", "approximateManagedInstanceCount"
        :type sort_by: str

        :param fields:
            The value to assign to the fields property of this RequestSummarizedJreUsageDetails.
        :type fields: list[oci.jms.models.SummarizeJreUsageFields]

        """
        self.swagger_types = {
            'time_start': 'datetime',
            'time_end': 'datetime',
            'jre_vendor': 'str',
            'jre_distribution': 'str',
            'jre_version': 'str',
            'application_id': 'str',
            'managed_instance_id': 'str',
            'sort_order': 'str',
            'sort_by': 'str',
            'fields': 'list[SummarizeJreUsageFields]'
        }

        self.attribute_map = {
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'jre_vendor': 'jreVendor',
            'jre_distribution': 'jreDistribution',
            'jre_version': 'jreVersion',
            'application_id': 'applicationId',
            'managed_instance_id': 'managedInstanceId',
            'sort_order': 'sortOrder',
            'sort_by': 'sortBy',
            'fields': 'fields'
        }

        self._time_start = None
        self._time_end = None
        self._jre_vendor = None
        self._jre_distribution = None
        self._jre_version = None
        self._application_id = None
        self._managed_instance_id = None
        self._sort_order = None
        self._sort_by = None
        self._fields = None

    @property
    def time_start(self):
        """
        Gets the time_start of this RequestSummarizedJreUsageDetails.
        The start of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time minus seven days.


        :return: The time_start of this RequestSummarizedJreUsageDetails.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this RequestSummarizedJreUsageDetails.
        The start of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time minus seven days.


        :param time_start: The time_start of this RequestSummarizedJreUsageDetails.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this RequestSummarizedJreUsageDetails.
        The end of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time.


        :return: The time_end of this RequestSummarizedJreUsageDetails.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this RequestSummarizedJreUsageDetails.
        The end of the time period during which resources are searched (formatted according to RFC3339). Defaults to current time.


        :param time_end: The time_end of this RequestSummarizedJreUsageDetails.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def jre_vendor(self):
        """
        Gets the jre_vendor of this RequestSummarizedJreUsageDetails.
        The vendor of the Java Runtime.


        :return: The jre_vendor of this RequestSummarizedJreUsageDetails.
        :rtype: str
        """
        return self._jre_vendor

    @jre_vendor.setter
    def jre_vendor(self, jre_vendor):
        """
        Sets the jre_vendor of this RequestSummarizedJreUsageDetails.
        The vendor of the Java Runtime.


        :param jre_vendor: The jre_vendor of this RequestSummarizedJreUsageDetails.
        :type: str
        """
        self._jre_vendor = jre_vendor

    @property
    def jre_distribution(self):
        """
        Gets the jre_distribution of this RequestSummarizedJreUsageDetails.
        The distribution of the Java Runtime.


        :return: The jre_distribution of this RequestSummarizedJreUsageDetails.
        :rtype: str
        """
        return self._jre_distribution

    @jre_distribution.setter
    def jre_distribution(self, jre_distribution):
        """
        Sets the jre_distribution of this RequestSummarizedJreUsageDetails.
        The distribution of the Java Runtime.


        :param jre_distribution: The jre_distribution of this RequestSummarizedJreUsageDetails.
        :type: str
        """
        self._jre_distribution = jre_distribution

    @property
    def jre_version(self):
        """
        Gets the jre_version of this RequestSummarizedJreUsageDetails.
        The version of the Java Runtime.


        :return: The jre_version of this RequestSummarizedJreUsageDetails.
        :rtype: str
        """
        return self._jre_version

    @jre_version.setter
    def jre_version(self, jre_version):
        """
        Sets the jre_version of this RequestSummarizedJreUsageDetails.
        The version of the Java Runtime.


        :param jre_version: The jre_version of this RequestSummarizedJreUsageDetails.
        :type: str
        """
        self._jre_version = jre_version

    @property
    def application_id(self):
        """
        Gets the application_id of this RequestSummarizedJreUsageDetails.
        The ID of the related application.


        :return: The application_id of this RequestSummarizedJreUsageDetails.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this RequestSummarizedJreUsageDetails.
        The ID of the related application.


        :param application_id: The application_id of this RequestSummarizedJreUsageDetails.
        :type: str
        """
        self._application_id = application_id

    @property
    def managed_instance_id(self):
        """
        Gets the managed_instance_id of this RequestSummarizedJreUsageDetails.
        The `OCID`__ of the related managed instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_instance_id of this RequestSummarizedJreUsageDetails.
        :rtype: str
        """
        return self._managed_instance_id

    @managed_instance_id.setter
    def managed_instance_id(self, managed_instance_id):
        """
        Sets the managed_instance_id of this RequestSummarizedJreUsageDetails.
        The `OCID`__ of the related managed instance.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_instance_id: The managed_instance_id of this RequestSummarizedJreUsageDetails.
        :type: str
        """
        self._managed_instance_id = managed_instance_id

    @property
    def sort_order(self):
        """
        Gets the sort_order of this RequestSummarizedJreUsageDetails.
        The sort order to use, either 'asc' or 'desc'.

        Allowed values for this property are: "ASC", "DESC"


        :return: The sort_order of this RequestSummarizedJreUsageDetails.
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """
        Sets the sort_order of this RequestSummarizedJreUsageDetails.
        The sort order to use, either 'asc' or 'desc'.


        :param sort_order: The sort_order of this RequestSummarizedJreUsageDetails.
        :type: str
        """
        allowed_values = ["ASC", "DESC"]
        if not value_allowed_none_or_none_sentinel(sort_order, allowed_values):
            raise ValueError(
                "Invalid value for `sort_order`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sort_order = sort_order

    @property
    def sort_by(self):
        """
        Gets the sort_by of this RequestSummarizedJreUsageDetails.
        The field to sort Java Runtime views. Only one sort order may be provided.
        Default order for _timeFirstSeen_, _timeLastSeen_, _version_, _approximateInstallationCount_,
        _approximateApplicationCount_ and _approximateManagedInstanceCount_  is **descending**.
        Default order for _distribution_ and _vendor_ is **ascending**. If no value is specified _timeLastSeen_ is default.

        Allowed values for this property are: "distribution", "timeFirstSeen", "timeLastSeen", "vendor", "version", "approximateInstallationCount", "approximateApplicationCount", "approximateManagedInstanceCount"


        :return: The sort_by of this RequestSummarizedJreUsageDetails.
        :rtype: str
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """
        Sets the sort_by of this RequestSummarizedJreUsageDetails.
        The field to sort Java Runtime views. Only one sort order may be provided.
        Default order for _timeFirstSeen_, _timeLastSeen_, _version_, _approximateInstallationCount_,
        _approximateApplicationCount_ and _approximateManagedInstanceCount_  is **descending**.
        Default order for _distribution_ and _vendor_ is **ascending**. If no value is specified _timeLastSeen_ is default.


        :param sort_by: The sort_by of this RequestSummarizedJreUsageDetails.
        :type: str
        """
        allowed_values = ["distribution", "timeFirstSeen", "timeLastSeen", "vendor", "version", "approximateInstallationCount", "approximateApplicationCount", "approximateManagedInstanceCount"]
        if not value_allowed_none_or_none_sentinel(sort_by, allowed_values):
            raise ValueError(
                "Invalid value for `sort_by`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sort_by = sort_by

    @property
    def fields(self):
        """
        Gets the fields of this RequestSummarizedJreUsageDetails.
        Additional fields to include into the returned model on top of the required ones.
        This parameter can also include 'approximateApplicationCount', 'approximateInstallationCount' and 'approximateManagedInstanceCount'.
        For example 'approximateApplicationCount,approximateManagedInstanceCount'.


        :return: The fields of this RequestSummarizedJreUsageDetails.
        :rtype: list[oci.jms.models.SummarizeJreUsageFields]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this RequestSummarizedJreUsageDetails.
        Additional fields to include into the returned model on top of the required ones.
        This parameter can also include 'approximateApplicationCount', 'approximateInstallationCount' and 'approximateManagedInstanceCount'.
        For example 'approximateApplicationCount,approximateManagedInstanceCount'.


        :param fields: The fields of this RequestSummarizedJreUsageDetails.
        :type: list[oci.jms.models.SummarizeJreUsageFields]
        """
        self._fields = fields

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateObjectStorageTierDetails(object):
    """
    To change the storage tier of an object, we specify the object name and the desired
    storage tier in the body. Objects can be moved between Standard and InfrequentAccess
    tiers and from Standard or InfrequentAccess tier to Archive tier. If a version id is
    specified, only the specified version of the object is moved to a different storage
    tier, else the current version is used.
    """

    #: A constant which can be used with the storage_tier property of a UpdateObjectStorageTierDetails.
    #: This constant has a value of "Standard"
    STORAGE_TIER_STANDARD = "Standard"

    #: A constant which can be used with the storage_tier property of a UpdateObjectStorageTierDetails.
    #: This constant has a value of "InfrequentAccess"
    STORAGE_TIER_INFREQUENT_ACCESS = "InfrequentAccess"

    #: A constant which can be used with the storage_tier property of a UpdateObjectStorageTierDetails.
    #: This constant has a value of "Archive"
    STORAGE_TIER_ARCHIVE = "Archive"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateObjectStorageTierDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object_name:
            The value to assign to the object_name property of this UpdateObjectStorageTierDetails.
        :type object_name: str

        :param storage_tier:
            The value to assign to the storage_tier property of this UpdateObjectStorageTierDetails.
            Allowed values for this property are: "Standard", "InfrequentAccess", "Archive"
        :type storage_tier: str

        :param version_id:
            The value to assign to the version_id property of this UpdateObjectStorageTierDetails.
        :type version_id: str

        """
        self.swagger_types = {
            'object_name': 'str',
            'storage_tier': 'str',
            'version_id': 'str'
        }

        self.attribute_map = {
            'object_name': 'objectName',
            'storage_tier': 'storageTier',
            'version_id': 'versionId'
        }

        self._object_name = None
        self._storage_tier = None
        self._version_id = None

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this UpdateObjectStorageTierDetails.
        An object for which the storage tier needs to be changed.


        :return: The object_name of this UpdateObjectStorageTierDetails.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this UpdateObjectStorageTierDetails.
        An object for which the storage tier needs to be changed.


        :param object_name: The object_name of this UpdateObjectStorageTierDetails.
        :type: str
        """
        self._object_name = object_name

    @property
    def storage_tier(self):
        """
        **[Required]** Gets the storage_tier of this UpdateObjectStorageTierDetails.
        The storage tier that the object should be moved to.

        Allowed values for this property are: "Standard", "InfrequentAccess", "Archive"


        :return: The storage_tier of this UpdateObjectStorageTierDetails.
        :rtype: str
        """
        return self._storage_tier

    @storage_tier.setter
    def storage_tier(self, storage_tier):
        """
        Sets the storage_tier of this UpdateObjectStorageTierDetails.
        The storage tier that the object should be moved to.


        :param storage_tier: The storage_tier of this UpdateObjectStorageTierDetails.
        :type: str
        """
        allowed_values = ["Standard", "InfrequentAccess", "Archive"]
        if not value_allowed_none_or_none_sentinel(storage_tier, allowed_values):
            raise ValueError(
                "Invalid value for `storage_tier`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._storage_tier = storage_tier

    @property
    def version_id(self):
        """
        Gets the version_id of this UpdateObjectStorageTierDetails.
        The versionId of the object. Current object version is used by default.


        :return: The version_id of this UpdateObjectStorageTierDetails.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """
        Sets the version_id of this UpdateObjectStorageTierDetails.
        The versionId of the object. Current object version is used by default.


        :param version_id: The version_id of this UpdateObjectStorageTierDetails.
        :type: str
        """
        self._version_id = version_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstalledPackageSummary(object):
    """
    A software package installed on a managed instance
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstalledPackageSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this InstalledPackageSummary.
        :type display_name: str

        :param name:
            The value to assign to the name property of this InstalledPackageSummary.
        :type name: str

        :param type:
            The value to assign to the type property of this InstalledPackageSummary.
        :type type: str

        :param version:
            The value to assign to the version property of this InstalledPackageSummary.
        :type version: str

        :param architecture:
            The value to assign to the architecture property of this InstalledPackageSummary.
        :type architecture: str

        :param install_time:
            The value to assign to the install_time property of this InstalledPackageSummary.
        :type install_time: str

        :param issued:
            The value to assign to the issued property of this InstalledPackageSummary.
        :type issued: str

        :param software_sources:
            The value to assign to the software_sources property of this InstalledPackageSummary.
        :type software_sources: list[oci.os_management.models.SoftwareSourceId]

        """
        self.swagger_types = {
            'display_name': 'str',
            'name': 'str',
            'type': 'str',
            'version': 'str',
            'architecture': 'str',
            'install_time': 'str',
            'issued': 'str',
            'software_sources': 'list[SoftwareSourceId]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'name': 'name',
            'type': 'type',
            'version': 'version',
            'architecture': 'architecture',
            'install_time': 'installTime',
            'issued': 'issued',
            'software_sources': 'softwareSources'
        }

        self._display_name = None
        self._name = None
        self._type = None
        self._version = None
        self._architecture = None
        self._install_time = None
        self._issued = None
        self._software_sources = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this InstalledPackageSummary.
        Package name


        :return: The display_name of this InstalledPackageSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this InstalledPackageSummary.
        Package name


        :param display_name: The display_name of this InstalledPackageSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def name(self):
        """
        **[Required]** Gets the name of this InstalledPackageSummary.
        Unique identifier for the package. NOTE - This is not an OCID


        :return: The name of this InstalledPackageSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this InstalledPackageSummary.
        Unique identifier for the package. NOTE - This is not an OCID


        :param name: The name of this InstalledPackageSummary.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this InstalledPackageSummary.
        Type of the package


        :return: The type of this InstalledPackageSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this InstalledPackageSummary.
        Type of the package


        :param type: The type of this InstalledPackageSummary.
        :type: str
        """
        self._type = type

    @property
    def version(self):
        """
        **[Required]** Gets the version of this InstalledPackageSummary.
        Version of the installed package


        :return: The version of this InstalledPackageSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this InstalledPackageSummary.
        Version of the installed package


        :param version: The version of this InstalledPackageSummary.
        :type: str
        """
        self._version = version

    @property
    def architecture(self):
        """
        Gets the architecture of this InstalledPackageSummary.
        The architecture for which this package was built


        :return: The architecture of this InstalledPackageSummary.
        :rtype: str
        """
        return self._architecture

    @architecture.setter
    def architecture(self, architecture):
        """
        Sets the architecture of this InstalledPackageSummary.
        The architecture for which this package was built


        :param architecture: The architecture of this InstalledPackageSummary.
        :type: str
        """
        self._architecture = architecture

    @property
    def install_time(self):
        """
        Gets the install_time of this InstalledPackageSummary.
        Install time of the package


        :return: The install_time of this InstalledPackageSummary.
        :rtype: str
        """
        return self._install_time

    @install_time.setter
    def install_time(self, install_time):
        """
        Sets the install_time of this InstalledPackageSummary.
        Install time of the package


        :param install_time: The install_time of this InstalledPackageSummary.
        :type: str
        """
        self._install_time = install_time

    @property
    def issued(self):
        """
        Gets the issued of this InstalledPackageSummary.
        date the package was issued by a providing erratum (if available)


        :return: The issued of this InstalledPackageSummary.
        :rtype: str
        """
        return self._issued

    @issued.setter
    def issued(self, issued):
        """
        Sets the issued of this InstalledPackageSummary.
        date the package was issued by a providing erratum (if available)


        :param issued: The issued of this InstalledPackageSummary.
        :type: str
        """
        self._issued = issued

    @property
    def software_sources(self):
        """
        Gets the software_sources of this InstalledPackageSummary.
        list of software sources that provide the software package


        :return: The software_sources of this InstalledPackageSummary.
        :rtype: list[oci.os_management.models.SoftwareSourceId]
        """
        return self._software_sources

    @software_sources.setter
    def software_sources(self, software_sources):
        """
        Sets the software_sources of this InstalledPackageSummary.
        list of software sources that provide the software package


        :param software_sources: The software_sources of this InstalledPackageSummary.
        :type: list[oci.os_management.models.SoftwareSourceId]
        """
        self._software_sources = software_sources

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RestoreObjectsDetails(object):
    """
    RestoreObjectsDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RestoreObjectsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object_name:
            The value to assign to the object_name property of this RestoreObjectsDetails.
        :type object_name: str

        :param hours:
            The value to assign to the hours property of this RestoreObjectsDetails.
        :type hours: int

        :param version_id:
            The value to assign to the version_id property of this RestoreObjectsDetails.
        :type version_id: str

        """
        self.swagger_types = {
            'object_name': 'str',
            'hours': 'int',
            'version_id': 'str'
        }

        self.attribute_map = {
            'object_name': 'objectName',
            'hours': 'hours',
            'version_id': 'versionId'
        }

        self._object_name = None
        self._hours = None
        self._version_id = None

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this RestoreObjectsDetails.
        An object that is in an archive storage tier and needs to be restored.


        :return: The object_name of this RestoreObjectsDetails.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this RestoreObjectsDetails.
        An object that is in an archive storage tier and needs to be restored.


        :param object_name: The object_name of this RestoreObjectsDetails.
        :type: str
        """
        self._object_name = object_name

    @property
    def hours(self):
        """
        Gets the hours of this RestoreObjectsDetails.
        The number of hours for which this object will be restored.
        By default objects will be restored for 24 hours. You can instead configure the duration using the hours parameter.


        :return: The hours of this RestoreObjectsDetails.
        :rtype: int
        """
        return self._hours

    @hours.setter
    def hours(self, hours):
        """
        Sets the hours of this RestoreObjectsDetails.
        The number of hours for which this object will be restored.
        By default objects will be restored for 24 hours. You can instead configure the duration using the hours parameter.


        :param hours: The hours of this RestoreObjectsDetails.
        :type: int
        """
        self._hours = hours

    @property
    def version_id(self):
        """
        Gets the version_id of this RestoreObjectsDetails.
        The versionId of the object to restore. Current object version is used by default.


        :return: The version_id of this RestoreObjectsDetails.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """
        Sets the version_id of this RestoreObjectsDetails.
        The versionId of the object to restore. Current object version is used by default.


        :param version_id: The version_id of this RestoreObjectsDetails.
        :type: str
        """
        self._version_id = version_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrivateEndpointSettings(object):
    """
    Optional settings if the stream pool is private.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PrivateEndpointSettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param subnet_id:
            The value to assign to the subnet_id property of this PrivateEndpointSettings.
        :type subnet_id: str

        :param private_endpoint_ip:
            The value to assign to the private_endpoint_ip property of this PrivateEndpointSettings.
        :type private_endpoint_ip: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this PrivateEndpointSettings.
        :type nsg_ids: list[str]

        """
        self.swagger_types = {
            'subnet_id': 'str',
            'private_endpoint_ip': 'str',
            'nsg_ids': 'list[str]'
        }

        self.attribute_map = {
            'subnet_id': 'subnetId',
            'private_endpoint_ip': 'privateEndpointIp',
            'nsg_ids': 'nsgIds'
        }

        self._subnet_id = None
        self._private_endpoint_ip = None
        self._nsg_ids = None

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this PrivateEndpointSettings.
        The subnet id from which the private stream pool can be accessed.
        Trying to access the streams from another network location will result in an error.


        :return: The subnet_id of this PrivateEndpointSettings.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this PrivateEndpointSettings.
        The subnet id from which the private stream pool can be accessed.
        Trying to access the streams from another network location will result in an error.


        :param subnet_id: The subnet_id of this PrivateEndpointSettings.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def private_endpoint_ip(self):
        """
        Gets the private_endpoint_ip of this PrivateEndpointSettings.
        The private IP associated with the stream pool in the associated subnetId.
        The stream pool's FQDN resolves to that IP and should be used - instead of the private IP - in order to not trigger any TLS issues.


        :return: The private_endpoint_ip of this PrivateEndpointSettings.
        :rtype: str
        """
        return self._private_endpoint_ip

    @private_endpoint_ip.setter
    def private_endpoint_ip(self, private_endpoint_ip):
        """
        Sets the private_endpoint_ip of this PrivateEndpointSettings.
        The private IP associated with the stream pool in the associated subnetId.
        The stream pool's FQDN resolves to that IP and should be used - instead of the private IP - in order to not trigger any TLS issues.


        :param private_endpoint_ip: The private_endpoint_ip of this PrivateEndpointSettings.
        :type: str
        """
        self._private_endpoint_ip = private_endpoint_ip

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this PrivateEndpointSettings.
        The optional list of network security groups that are associated with the private endpoint of the stream pool.


        :return: The nsg_ids of this PrivateEndpointSettings.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this PrivateEndpointSettings.
        The optional list of network security groups that are associated with the private endpoint of the stream pool.


        :param nsg_ids: The nsg_ids of this PrivateEndpointSettings.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsLookup(object):
    """
    LogAnalyticsLookup
    """

    #: A constant which can be used with the type property of a LogAnalyticsLookup.
    #: This constant has a value of "Lookup"
    TYPE_LOOKUP = "Lookup"

    #: A constant which can be used with the type property of a LogAnalyticsLookup.
    #: This constant has a value of "Dictionary"
    TYPE_DICTIONARY = "Dictionary"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsLookup object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param active_edit_version:
            The value to assign to the active_edit_version property of this LogAnalyticsLookup.
        :type active_edit_version: int

        :param canonical_link:
            The value to assign to the canonical_link property of this LogAnalyticsLookup.
        :type canonical_link: str

        :param description:
            The value to assign to the description property of this LogAnalyticsLookup.
        :type description: str

        :param edit_version:
            The value to assign to the edit_version property of this LogAnalyticsLookup.
        :type edit_version: int

        :param fields:
            The value to assign to the fields property of this LogAnalyticsLookup.
        :type fields: list[oci.log_analytics.models.LookupField]

        :param lookup_reference:
            The value to assign to the lookup_reference property of this LogAnalyticsLookup.
        :type lookup_reference: int

        :param lookup_reference_string:
            The value to assign to the lookup_reference_string property of this LogAnalyticsLookup.
        :type lookup_reference_string: str

        :param type:
            The value to assign to the type property of this LogAnalyticsLookup.
            Allowed values for this property are: "Lookup", "Dictionary", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param name:
            The value to assign to the name property of this LogAnalyticsLookup.
        :type name: str

        :param is_built_in:
            The value to assign to the is_built_in property of this LogAnalyticsLookup.
        :type is_built_in: int

        :param is_hidden:
            The value to assign to the is_hidden property of this LogAnalyticsLookup.
        :type is_hidden: bool

        :param lookup_display_name:
            The value to assign to the lookup_display_name property of this LogAnalyticsLookup.
        :type lookup_display_name: str

        :param referring_sources:
            The value to assign to the referring_sources property of this LogAnalyticsLookup.
        :type referring_sources: oci.log_analytics.models.AutoLookups

        :param status_summary:
            The value to assign to the status_summary property of this LogAnalyticsLookup.
        :type status_summary: oci.log_analytics.models.StatusSummary

        :param time_updated:
            The value to assign to the time_updated property of this LogAnalyticsLookup.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'active_edit_version': 'int',
            'canonical_link': 'str',
            'description': 'str',
            'edit_version': 'int',
            'fields': 'list[LookupField]',
            'lookup_reference': 'int',
            'lookup_reference_string': 'str',
            'type': 'str',
            'name': 'str',
            'is_built_in': 'int',
            'is_hidden': 'bool',
            'lookup_display_name': 'str',
            'referring_sources': 'AutoLookups',
            'status_summary': 'StatusSummary',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'active_edit_version': 'activeEditVersion',
            'canonical_link': 'canonicalLink',
            'description': 'description',
            'edit_version': 'editVersion',
            'fields': 'fields',
            'lookup_reference': 'lookupReference',
            'lookup_reference_string': 'lookupReferenceString',
            'type': 'type',
            'name': 'name',
            'is_built_in': 'isBuiltIn',
            'is_hidden': 'isHidden',
            'lookup_display_name': 'lookupDisplayName',
            'referring_sources': 'referringSources',
            'status_summary': 'statusSummary',
            'time_updated': 'timeUpdated'
        }

        self._active_edit_version = None
        self._canonical_link = None
        self._description = None
        self._edit_version = None
        self._fields = None
        self._lookup_reference = None
        self._lookup_reference_string = None
        self._type = None
        self._name = None
        self._is_built_in = None
        self._is_hidden = None
        self._lookup_display_name = None
        self._referring_sources = None
        self._status_summary = None
        self._time_updated = None

    @property
    def active_edit_version(self):
        """
        Gets the active_edit_version of this LogAnalyticsLookup.
        The active edit version.


        :return: The active_edit_version of this LogAnalyticsLookup.
        :rtype: int
        """
        return self._active_edit_version

    @active_edit_version.setter
    def active_edit_version(self, active_edit_version):
        """
        Sets the active_edit_version of this LogAnalyticsLookup.
        The active edit version.


        :param active_edit_version: The active_edit_version of this LogAnalyticsLookup.
        :type: int
        """
        self._active_edit_version = active_edit_version

    @property
    def canonical_link(self):
        """
        Gets the canonical_link of this LogAnalyticsLookup.
        The canonical link.


        :return: The canonical_link of this LogAnalyticsLookup.
        :rtype: str
        """
        return self._canonical_link

    @canonical_link.setter
    def canonical_link(self, canonical_link):
        """
        Sets the canonical_link of this LogAnalyticsLookup.
        The canonical link.


        :param canonical_link: The canonical_link of this LogAnalyticsLookup.
        :type: str
        """
        self._canonical_link = canonical_link

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsLookup.
        The lookup description.


        :return: The description of this LogAnalyticsLookup.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsLookup.
        The lookup description.


        :param description: The description of this LogAnalyticsLookup.
        :type: str
        """
        self._description = description

    @property
    def edit_version(self):
        """
        Gets the edit_version of this LogAnalyticsLookup.
        The edit version.


        :return: The edit_version of this LogAnalyticsLookup.
        :rtype: int
        """
        return self._edit_version

    @edit_version.setter
    def edit_version(self, edit_version):
        """
        Sets the edit_version of this LogAnalyticsLookup.
        The edit version.


        :param edit_version: The edit_version of this LogAnalyticsLookup.
        :type: int
        """
        self._edit_version = edit_version

    @property
    def fields(self):
        """
        Gets the fields of this LogAnalyticsLookup.
        The lookup fields.


        :return: The fields of this LogAnalyticsLookup.
        :rtype: list[oci.log_analytics.models.LookupField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this LogAnalyticsLookup.
        The lookup fields.


        :param fields: The fields of this LogAnalyticsLookup.
        :type: list[oci.log_analytics.models.LookupField]
        """
        self._fields = fields

    @property
    def lookup_reference(self):
        """
        Gets the lookup_reference of this LogAnalyticsLookup.
        The lookup reference as an integer.


        :return: The lookup_reference of this LogAnalyticsLookup.
        :rtype: int
        """
        return self._lookup_reference

    @lookup_reference.setter
    def lookup_reference(self, lookup_reference):
        """
        Sets the lookup_reference of this LogAnalyticsLookup.
        The lookup reference as an integer.


        :param lookup_reference: The lookup_reference of this LogAnalyticsLookup.
        :type: int
        """
        self._lookup_reference = lookup_reference

    @property
    def lookup_reference_string(self):
        """
        Gets the lookup_reference_string of this LogAnalyticsLookup.
        The lookup reference as a string.


        :return: The lookup_reference_string of this LogAnalyticsLookup.
        :rtype: str
        """
        return self._lookup_reference_string

    @lookup_reference_string.setter
    def lookup_reference_string(self, lookup_reference_string):
        """
        Sets the lookup_reference_string of this LogAnalyticsLookup.
        The lookup reference as a string.


        :param lookup_reference_string: The lookup_reference_string of this LogAnalyticsLookup.
        :type: str
        """
        self._lookup_reference_string = lookup_reference_string

    @property
    def type(self):
        """
        Gets the type of this LogAnalyticsLookup.
        The lookup type.  Valid values are LOOKUP or DICTIONARY.

        Allowed values for this property are: "Lookup", "Dictionary", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this LogAnalyticsLookup.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this LogAnalyticsLookup.
        The lookup type.  Valid values are LOOKUP or DICTIONARY.


        :param type: The type of this LogAnalyticsLookup.
        :type: str
        """
        allowed_values = ["Lookup", "Dictionary"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsLookup.
        The lookup name.


        :return: The name of this LogAnalyticsLookup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsLookup.
        The lookup name.


        :param name: The name of this LogAnalyticsLookup.
        :type: str
        """
        self._name = name

    @property
    def is_built_in(self):
        """
        Gets the is_built_in of this LogAnalyticsLookup.
        A flag indicating if the lookup is custom (user-defined) or
        built in.


        :return: The is_built_in of this LogAnalyticsLookup.
        :rtype: int
        """
        return self._is_built_in

    @is_built_in.setter
    def is_built_in(self, is_built_in):
        """
        Sets the is_built_in of this LogAnalyticsLookup.
        A flag indicating if the lookup is custom (user-defined) or
        built in.


        :param is_built_in: The is_built_in of this LogAnalyticsLookup.
        :type: int
        """
        self._is_built_in = is_built_in

    @property
    def is_hidden(self):
        """
        Gets the is_hidden of this LogAnalyticsLookup.
        A flag indicating if the lookup is hidden or not.  A hidden lookup will
        not be returned in list operations by default.


        :return: The is_hidden of this LogAnalyticsLookup.
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """
        Sets the is_hidden of this LogAnalyticsLookup.
        A flag indicating if the lookup is hidden or not.  A hidden lookup will
        not be returned in list operations by default.


        :param is_hidden: The is_hidden of this LogAnalyticsLookup.
        :type: bool
        """
        self._is_hidden = is_hidden

    @property
    def lookup_display_name(self):
        """
        Gets the lookup_display_name of this LogAnalyticsLookup.
        The lookup display name.


        :return: The lookup_display_name of this LogAnalyticsLookup.
        :rtype: str
        """
        return self._lookup_display_name

    @lookup_display_name.setter
    def lookup_display_name(self, lookup_display_name):
        """
        Sets the lookup_display_name of this LogAnalyticsLookup.
        The lookup display name.


        :param lookup_display_name: The lookup_display_name of this LogAnalyticsLookup.
        :type: str
        """
        self._lookup_display_name = lookup_display_name

    @property
    def referring_sources(self):
        """
        Gets the referring_sources of this LogAnalyticsLookup.

        :return: The referring_sources of this LogAnalyticsLookup.
        :rtype: oci.log_analytics.models.AutoLookups
        """
        return self._referring_sources

    @referring_sources.setter
    def referring_sources(self, referring_sources):
        """
        Sets the referring_sources of this LogAnalyticsLookup.

        :param referring_sources: The referring_sources of this LogAnalyticsLookup.
        :type: oci.log_analytics.models.AutoLookups
        """
        self._referring_sources = referring_sources

    @property
    def status_summary(self):
        """
        Gets the status_summary of this LogAnalyticsLookup.

        :return: The status_summary of this LogAnalyticsLookup.
        :rtype: oci.log_analytics.models.StatusSummary
        """
        return self._status_summary

    @status_summary.setter
    def status_summary(self, status_summary):
        """
        Sets the status_summary of this LogAnalyticsLookup.

        :param status_summary: The status_summary of this LogAnalyticsLookup.
        :type: oci.log_analytics.models.StatusSummary
        """
        self._status_summary = status_summary

    @property
    def time_updated(self):
        """
        Gets the time_updated of this LogAnalyticsLookup.
        The last updated date.


        :return: The time_updated of this LogAnalyticsLookup.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this LogAnalyticsLookup.
        The last updated date.


        :param time_updated: The time_updated of this LogAnalyticsLookup.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .target_details import TargetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStorageTargetDetails(TargetDetails):
    """
    The bucket used for the Object Storage target.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStorageTargetDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.sch.models.ObjectStorageTargetDetails.kind` attribute
        of this class is ``objectStorage`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this ObjectStorageTargetDetails.
            Allowed values for this property are: "functions", "loggingAnalytics", "monitoring", "notifications", "objectStorage", "streaming"
        :type kind: str

        :param namespace:
            The value to assign to the namespace property of this ObjectStorageTargetDetails.
        :type namespace: str

        :param bucket_name:
            The value to assign to the bucket_name property of this ObjectStorageTargetDetails.
        :type bucket_name: str

        :param object_name_prefix:
            The value to assign to the object_name_prefix property of this ObjectStorageTargetDetails.
        :type object_name_prefix: str

        :param batch_rollover_size_in_mbs:
            The value to assign to the batch_rollover_size_in_mbs property of this ObjectStorageTargetDetails.
        :type batch_rollover_size_in_mbs: int

        :param batch_rollover_time_in_ms:
            The value to assign to the batch_rollover_time_in_ms property of this ObjectStorageTargetDetails.
        :type batch_rollover_time_in_ms: int

        """
        self.swagger_types = {
            'kind': 'str',
            'namespace': 'str',
            'bucket_name': 'str',
            'object_name_prefix': 'str',
            'batch_rollover_size_in_mbs': 'int',
            'batch_rollover_time_in_ms': 'int'
        }

        self.attribute_map = {
            'kind': 'kind',
            'namespace': 'namespace',
            'bucket_name': 'bucketName',
            'object_name_prefix': 'objectNamePrefix',
            'batch_rollover_size_in_mbs': 'batchRolloverSizeInMBs',
            'batch_rollover_time_in_ms': 'batchRolloverTimeInMs'
        }

        self._kind = None
        self._namespace = None
        self._bucket_name = None
        self._object_name_prefix = None
        self._batch_rollover_size_in_mbs = None
        self._batch_rollover_time_in_ms = None
        self._kind = 'objectStorage'

    @property
    def namespace(self):
        """
        Gets the namespace of this ObjectStorageTargetDetails.
        The namespace.


        :return: The namespace of this ObjectStorageTargetDetails.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this ObjectStorageTargetDetails.
        The namespace.


        :param namespace: The namespace of this ObjectStorageTargetDetails.
        :type: str
        """
        self._namespace = namespace

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this ObjectStorageTargetDetails.
        The name of the bucket. Avoid entering confidential information.


        :return: The bucket_name of this ObjectStorageTargetDetails.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this ObjectStorageTargetDetails.
        The name of the bucket. Avoid entering confidential information.


        :param bucket_name: The bucket_name of this ObjectStorageTargetDetails.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def object_name_prefix(self):
        """
        Gets the object_name_prefix of this ObjectStorageTargetDetails.
        The prefix of the objects. Avoid entering confidential information.


        :return: The object_name_prefix of this ObjectStorageTargetDetails.
        :rtype: str
        """
        return self._object_name_prefix

    @object_name_prefix.setter
    def object_name_prefix(self, object_name_prefix):
        """
        Sets the object_name_prefix of this ObjectStorageTargetDetails.
        The prefix of the objects. Avoid entering confidential information.


        :param object_name_prefix: The object_name_prefix of this ObjectStorageTargetDetails.
        :type: str
        """
        self._object_name_prefix = object_name_prefix

    @property
    def batch_rollover_size_in_mbs(self):
        """
        Gets the batch_rollover_size_in_mbs of this ObjectStorageTargetDetails.
        The batch rollover size in megabytes.


        :return: The batch_rollover_size_in_mbs of this ObjectStorageTargetDetails.
        :rtype: int
        """
        return self._batch_rollover_size_in_mbs

    @batch_rollover_size_in_mbs.setter
    def batch_rollover_size_in_mbs(self, batch_rollover_size_in_mbs):
        """
        Sets the batch_rollover_size_in_mbs of this ObjectStorageTargetDetails.
        The batch rollover size in megabytes.


        :param batch_rollover_size_in_mbs: The batch_rollover_size_in_mbs of this ObjectStorageTargetDetails.
        :type: int
        """
        self._batch_rollover_size_in_mbs = batch_rollover_size_in_mbs

    @property
    def batch_rollover_time_in_ms(self):
        """
        Gets the batch_rollover_time_in_ms of this ObjectStorageTargetDetails.
        The batch rollover time in milliseconds.


        :return: The batch_rollover_time_in_ms of this ObjectStorageTargetDetails.
        :rtype: int
        """
        return self._batch_rollover_time_in_ms

    @batch_rollover_time_in_ms.setter
    def batch_rollover_time_in_ms(self, batch_rollover_time_in_ms):
        """
        Sets the batch_rollover_time_in_ms of this ObjectStorageTargetDetails.
        The batch rollover time in milliseconds.


        :param batch_rollover_time_in_ms: The batch_rollover_time_in_ms of this ObjectStorageTargetDetails.
        :type: int
        """
        self._batch_rollover_time_in_ms = batch_rollover_time_in_ms

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchTermSummary(object):
    """
    Summary of a term associated with an object. This is a brief summary returned as part of the search result.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SearchTermSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this SearchTermSummary.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this SearchTermSummary.
        :type display_name: str

        :param glossary_key:
            The value to assign to the glossary_key property of this SearchTermSummary.
        :type glossary_key: str

        :param glossary_name:
            The value to assign to the glossary_name property of this SearchTermSummary.
        :type glossary_name: str

        :param parent_term_key:
            The value to assign to the parent_term_key property of this SearchTermSummary.
        :type parent_term_key: str

        :param parent_term_name:
            The value to assign to the parent_term_name property of this SearchTermSummary.
        :type parent_term_name: str

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'glossary_key': 'str',
            'glossary_name': 'str',
            'parent_term_key': 'str',
            'parent_term_name': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'glossary_key': 'glossaryKey',
            'glossary_name': 'glossaryName',
            'parent_term_key': 'parentTermKey',
            'parent_term_name': 'parentTermName'
        }

        self._key = None
        self._display_name = None
        self._glossary_key = None
        self._glossary_name = None
        self._parent_term_key = None
        self._parent_term_name = None

    @property
    def key(self):
        """
        Gets the key of this SearchTermSummary.
        Unique term key that is immutable.


        :return: The key of this SearchTermSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this SearchTermSummary.
        Unique term key that is immutable.


        :param key: The key of this SearchTermSummary.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this SearchTermSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this SearchTermSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SearchTermSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this SearchTermSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def glossary_key(self):
        """
        Gets the glossary_key of this SearchTermSummary.
        Unique id of the parent glossary.


        :return: The glossary_key of this SearchTermSummary.
        :rtype: str
        """
        return self._glossary_key

    @glossary_key.setter
    def glossary_key(self, glossary_key):
        """
        Sets the glossary_key of this SearchTermSummary.
        Unique id of the parent glossary.


        :param glossary_key: The glossary_key of this SearchTermSummary.
        :type: str
        """
        self._glossary_key = glossary_key

    @property
    def glossary_name(self):
        """
        Gets the glossary_name of this SearchTermSummary.
        Name of the parent glossary.


        :return: The glossary_name of this SearchTermSummary.
        :rtype: str
        """
        return self._glossary_name

    @glossary_name.setter
    def glossary_name(self, glossary_name):
        """
        Sets the glossary_name of this SearchTermSummary.
        Name of the parent glossary.


        :param glossary_name: The glossary_name of this SearchTermSummary.
        :type: str
        """
        self._glossary_name = glossary_name

    @property
    def parent_term_key(self):
        """
        Gets the parent_term_key of this SearchTermSummary.
        This terms parent term key. Will be null if the term has no parent term.


        :return: The parent_term_key of this SearchTermSummary.
        :rtype: str
        """
        return self._parent_term_key

    @parent_term_key.setter
    def parent_term_key(self, parent_term_key):
        """
        Sets the parent_term_key of this SearchTermSummary.
        This terms parent term key. Will be null if the term has no parent term.


        :param parent_term_key: The parent_term_key of this SearchTermSummary.
        :type: str
        """
        self._parent_term_key = parent_term_key

    @property
    def parent_term_name(self):
        """
        Gets the parent_term_name of this SearchTermSummary.
        Name of the parent term key. Will be null if the term has no parent term.


        :return: The parent_term_name of this SearchTermSummary.
        :rtype: str
        """
        return self._parent_term_name

    @parent_term_name.setter
    def parent_term_name(self, parent_term_name):
        """
        Sets the parent_term_name of this SearchTermSummary.
        Name of the parent term key. Will be null if the term has no parent term.


        :param parent_term_name: The parent_term_name of this SearchTermSummary.
        :type: str
        """
        self._parent_term_name = parent_term_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ValidatePatternDetails(object):
    """
    Validate pattern using the expression and file list.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ValidatePatternDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param expression:
            The value to assign to the expression property of this ValidatePatternDetails.
        :type expression: str

        :param check_file_path_list:
            The value to assign to the check_file_path_list property of this ValidatePatternDetails.
        :type check_file_path_list: list[str]

        :param check_failure_limit:
            The value to assign to the check_failure_limit property of this ValidatePatternDetails.
        :type check_failure_limit: int

        """
        self.swagger_types = {
            'expression': 'str',
            'check_file_path_list': 'list[str]',
            'check_failure_limit': 'int'
        }

        self.attribute_map = {
            'expression': 'expression',
            'check_file_path_list': 'checkFilePathList',
            'check_failure_limit': 'checkFailureLimit'
        }

        self._expression = None
        self._check_file_path_list = None
        self._check_failure_limit = None

    @property
    def expression(self):
        """
        Gets the expression of this ValidatePatternDetails.
        The expression used in the pattern that may include qualifiers. Refer to the user documentation for details of the format and examples.


        :return: The expression of this ValidatePatternDetails.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """
        Sets the expression of this ValidatePatternDetails.
        The expression used in the pattern that may include qualifiers. Refer to the user documentation for details of the format and examples.


        :param expression: The expression of this ValidatePatternDetails.
        :type: str
        """
        self._expression = expression

    @property
    def check_file_path_list(self):
        """
        Gets the check_file_path_list of this ValidatePatternDetails.
        List of file paths against which the expression can be tried, as a check. This documents, for reference
        purposes, some example objects a pattern is meant to work with.

        If provided with the request,this overrides the list which already exists as part of the pattern, if any.


        :return: The check_file_path_list of this ValidatePatternDetails.
        :rtype: list[str]
        """
        return self._check_file_path_list

    @check_file_path_list.setter
    def check_file_path_list(self, check_file_path_list):
        """
        Sets the check_file_path_list of this ValidatePatternDetails.
        List of file paths against which the expression can be tried, as a check. This documents, for reference
        purposes, some example objects a pattern is meant to work with.

        If provided with the request,this overrides the list which already exists as part of the pattern, if any.


        :param check_file_path_list: The check_file_path_list of this ValidatePatternDetails.
        :type: list[str]
        """
        self._check_file_path_list = check_file_path_list

    @property
    def check_failure_limit(self):
        """
        Gets the check_failure_limit of this ValidatePatternDetails.
        The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails.
        Optional, if checkFilePathList is provided.

        If provided with the request, this overrides the value which already exists as part of the pattern, if any.


        :return: The check_failure_limit of this ValidatePatternDetails.
        :rtype: int
        """
        return self._check_failure_limit

    @check_failure_limit.setter
    def check_failure_limit(self, check_failure_limit):
        """
        Sets the check_failure_limit of this ValidatePatternDetails.
        The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails.
        Optional, if checkFilePathList is provided.

        If provided with the request, this overrides the value which already exists as part of the pattern, if any.


        :param check_failure_limit: The check_failure_limit of this ValidatePatternDetails.
        :type: int
        """
        self._check_failure_limit = check_failure_limit

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ListingPackage(object):
    """
    A base object for all types of listing packages.
    """

    #: A constant which can be used with the package_type property of a ListingPackage.
    #: This constant has a value of "ORCHESTRATION"
    PACKAGE_TYPE_ORCHESTRATION = "ORCHESTRATION"

    #: A constant which can be used with the package_type property of a ListingPackage.
    #: This constant has a value of "IMAGE"
    PACKAGE_TYPE_IMAGE = "IMAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new ListingPackage object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.marketplace.models.OrchestrationListingPackage`
        * :class:`~oci.marketplace.models.ImageListingPackage`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this ListingPackage.
        :type description: str

        :param listing_id:
            The value to assign to the listing_id property of this ListingPackage.
        :type listing_id: str

        :param version:
            The value to assign to the version property of this ListingPackage.
        :type version: str

        :param package_type:
            The value to assign to the package_type property of this ListingPackage.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type package_type: str

        :param pricing:
            The value to assign to the pricing property of this ListingPackage.
        :type pricing: oci.marketplace.models.PricingModel

        :param resource_id:
            The value to assign to the resource_id property of this ListingPackage.
        :type resource_id: str

        :param time_created:
            The value to assign to the time_created property of this ListingPackage.
        :type time_created: datetime

        :param operating_system:
            The value to assign to the operating_system property of this ListingPackage.
        :type operating_system: oci.marketplace.models.OperatingSystem

        """
        self.swagger_types = {
            'description': 'str',
            'listing_id': 'str',
            'version': 'str',
            'package_type': 'str',
            'pricing': 'PricingModel',
            'resource_id': 'str',
            'time_created': 'datetime',
            'operating_system': 'OperatingSystem'
        }

        self.attribute_map = {
            'description': 'description',
            'listing_id': 'listingId',
            'version': 'version',
            'package_type': 'packageType',
            'pricing': 'pricing',
            'resource_id': 'resourceId',
            'time_created': 'timeCreated',
            'operating_system': 'operatingSystem'
        }

        self._description = None
        self._listing_id = None
        self._version = None
        self._package_type = None
        self._pricing = None
        self._resource_id = None
        self._time_created = None
        self._operating_system = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['packageType']

        if type == 'ORCHESTRATION':
            return 'OrchestrationListingPackage'

        if type == 'IMAGE':
            return 'ImageListingPackage'
        else:
            return 'ListingPackage'

    @property
    def description(self):
        """
        Gets the description of this ListingPackage.
        Description of this package.


        :return: The description of this ListingPackage.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ListingPackage.
        Description of this package.


        :param description: The description of this ListingPackage.
        :type: str
        """
        self._description = description

    @property
    def listing_id(self):
        """
        **[Required]** Gets the listing_id of this ListingPackage.
        The ID of the listing this package belongs to.


        :return: The listing_id of this ListingPackage.
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """
        Sets the listing_id of this ListingPackage.
        The ID of the listing this package belongs to.


        :param listing_id: The listing_id of this ListingPackage.
        :type: str
        """
        self._listing_id = listing_id

    @property
    def version(self):
        """
        **[Required]** Gets the version of this ListingPackage.
        The package version.


        :return: The version of this ListingPackage.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ListingPackage.
        The package version.


        :param version: The version of this ListingPackage.
        :type: str
        """
        self._version = version

    @property
    def package_type(self):
        """
        **[Required]** Gets the package_type of this ListingPackage.
        The specified package's type.

        Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The package_type of this ListingPackage.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this ListingPackage.
        The specified package's type.


        :param package_type: The package_type of this ListingPackage.
        :type: str
        """
        allowed_values = ["ORCHESTRATION", "IMAGE"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            package_type = 'UNKNOWN_ENUM_VALUE'
        self._package_type = package_type

    @property
    def pricing(self):
        """
        Gets the pricing of this ListingPackage.

        :return: The pricing of this ListingPackage.
        :rtype: oci.marketplace.models.PricingModel
        """
        return self._pricing

    @pricing.setter
    def pricing(self, pricing):
        """
        Sets the pricing of this ListingPackage.

        :param pricing: The pricing of this ListingPackage.
        :type: oci.marketplace.models.PricingModel
        """
        self._pricing = pricing

    @property
    def resource_id(self):
        """
        Gets the resource_id of this ListingPackage.
        The unique identifier for the package resource.


        :return: The resource_id of this ListingPackage.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this ListingPackage.
        The unique identifier for the package resource.


        :param resource_id: The resource_id of this ListingPackage.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def time_created(self):
        """
        Gets the time_created of this ListingPackage.
        The date and time this listing package was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ListingPackage.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ListingPackage.
        The date and time this listing package was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ListingPackage.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def operating_system(self):
        """
        Gets the operating_system of this ListingPackage.

        :return: The operating_system of this ListingPackage.
        :rtype: oci.marketplace.models.OperatingSystem
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """
        Sets the operating_system of this ListingPackage.

        :param operating_system: The operating_system of this ListingPackage.
        :type: oci.marketplace.models.OperatingSystem
        """
        self._operating_system = operating_system

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BudgetSummary(object):
    """
    A budget.
    """

    #: A constant which can be used with the reset_period property of a BudgetSummary.
    #: This constant has a value of "MONTHLY"
    RESET_PERIOD_MONTHLY = "MONTHLY"

    #: A constant which can be used with the target_type property of a BudgetSummary.
    #: This constant has a value of "COMPARTMENT"
    TARGET_TYPE_COMPARTMENT = "COMPARTMENT"

    #: A constant which can be used with the target_type property of a BudgetSummary.
    #: This constant has a value of "TAG"
    TARGET_TYPE_TAG = "TAG"

    #: A constant which can be used with the lifecycle_state property of a BudgetSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a BudgetSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new BudgetSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this BudgetSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this BudgetSummary.
        :type compartment_id: str

        :param target_compartment_id:
            The value to assign to the target_compartment_id property of this BudgetSummary.
        :type target_compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this BudgetSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this BudgetSummary.
        :type description: str

        :param amount:
            The value to assign to the amount property of this BudgetSummary.
        :type amount: float

        :param reset_period:
            The value to assign to the reset_period property of this BudgetSummary.
            Allowed values for this property are: "MONTHLY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type reset_period: str

        :param budget_processing_period_start_offset:
            The value to assign to the budget_processing_period_start_offset property of this BudgetSummary.
        :type budget_processing_period_start_offset: int

        :param target_type:
            The value to assign to the target_type property of this BudgetSummary.
            Allowed values for this property are: "COMPARTMENT", "TAG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type target_type: str

        :param targets:
            The value to assign to the targets property of this BudgetSummary.
        :type targets: list[str]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this BudgetSummary.
            Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param alert_rule_count:
            The value to assign to the alert_rule_count property of this BudgetSummary.
        :type alert_rule_count: int

        :param version:
            The value to assign to the version property of this BudgetSummary.
        :type version: int

        :param actual_spend:
            The value to assign to the actual_spend property of this BudgetSummary.
        :type actual_spend: float

        :param forecasted_spend:
            The value to assign to the forecasted_spend property of this BudgetSummary.
        :type forecasted_spend: float

        :param time_spend_computed:
            The value to assign to the time_spend_computed property of this BudgetSummary.
        :type time_spend_computed: datetime

        :param time_created:
            The value to assign to the time_created property of this BudgetSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this BudgetSummary.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this BudgetSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this BudgetSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'target_compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'amount': 'float',
            'reset_period': 'str',
            'budget_processing_period_start_offset': 'int',
            'target_type': 'str',
            'targets': 'list[str]',
            'lifecycle_state': 'str',
            'alert_rule_count': 'int',
            'version': 'int',
            'actual_spend': 'float',
            'forecasted_spend': 'float',
            'time_spend_computed': 'datetime',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'target_compartment_id': 'targetCompartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'amount': 'amount',
            'reset_period': 'resetPeriod',
            'budget_processing_period_start_offset': 'budgetProcessingPeriodStartOffset',
            'target_type': 'targetType',
            'targets': 'targets',
            'lifecycle_state': 'lifecycleState',
            'alert_rule_count': 'alertRuleCount',
            'version': 'version',
            'actual_spend': 'actualSpend',
            'forecasted_spend': 'forecastedSpend',
            'time_spend_computed': 'timeSpendComputed',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._target_compartment_id = None
        self._display_name = None
        self._description = None
        self._amount = None
        self._reset_period = None
        self._budget_processing_period_start_offset = None
        self._target_type = None
        self._targets = None
        self._lifecycle_state = None
        self._alert_rule_count = None
        self._version = None
        self._actual_spend = None
        self._forecasted_spend = None
        self._time_spend_computed = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BudgetSummary.
        The OCID of the budget


        :return: The id of this BudgetSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BudgetSummary.
        The OCID of the budget


        :param id: The id of this BudgetSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this BudgetSummary.
        The OCID of the compartment


        :return: The compartment_id of this BudgetSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this BudgetSummary.
        The OCID of the compartment


        :param compartment_id: The compartment_id of this BudgetSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def target_compartment_id(self):
        """
        Gets the target_compartment_id of this BudgetSummary.
        This is DEPRECATED. For backwards compatability, the property will be populated when
        targetType is \"COMPARTMENT\" AND targets contains EXACT ONE target compartment ocid.
        For all other scenarios, this property will be left empty.


        :return: The target_compartment_id of this BudgetSummary.
        :rtype: str
        """
        return self._target_compartment_id

    @target_compartment_id.setter
    def target_compartment_id(self, target_compartment_id):
        """
        Sets the target_compartment_id of this BudgetSummary.
        This is DEPRECATED. For backwards compatability, the property will be populated when
        targetType is \"COMPARTMENT\" AND targets contains EXACT ONE target compartment ocid.
        For all other scenarios, this property will be left empty.


        :param target_compartment_id: The target_compartment_id of this BudgetSummary.
        :type: str
        """
        self._target_compartment_id = target_compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this BudgetSummary.
        The display name of the budget.


        :return: The display_name of this BudgetSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BudgetSummary.
        The display name of the budget.


        :param display_name: The display_name of this BudgetSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this BudgetSummary.
        The description of the budget.


        :return: The description of this BudgetSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BudgetSummary.
        The description of the budget.


        :param description: The description of this BudgetSummary.
        :type: str
        """
        self._description = description

    @property
    def amount(self):
        """
        **[Required]** Gets the amount of this BudgetSummary.
        The amount of the budget expressed in the currency of the customer's rate card.


        :return: The amount of this BudgetSummary.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this BudgetSummary.
        The amount of the budget expressed in the currency of the customer's rate card.


        :param amount: The amount of this BudgetSummary.
        :type: float
        """
        self._amount = amount

    @property
    def reset_period(self):
        """
        **[Required]** Gets the reset_period of this BudgetSummary.
        The reset period for the budget.

        Allowed values for this property are: "MONTHLY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The reset_period of this BudgetSummary.
        :rtype: str
        """
        return self._reset_period

    @reset_period.setter
    def reset_period(self, reset_period):
        """
        Sets the reset_period of this BudgetSummary.
        The reset period for the budget.


        :param reset_period: The reset_period of this BudgetSummary.
        :type: str
        """
        allowed_values = ["MONTHLY"]
        if not value_allowed_none_or_none_sentinel(reset_period, allowed_values):
            reset_period = 'UNKNOWN_ENUM_VALUE'
        self._reset_period = reset_period

    @property
    def budget_processing_period_start_offset(self):
        """
        Gets the budget_processing_period_start_offset of this BudgetSummary.
        The number of days offset from the first day of the month, at which the budget processing period starts. In months that have fewer days than this value, processing will begin on the last day of that month. For example, for a value of 12, processing starts every month on the 12th at midnight.


        :return: The budget_processing_period_start_offset of this BudgetSummary.
        :rtype: int
        """
        return self._budget_processing_period_start_offset

    @budget_processing_period_start_offset.setter
    def budget_processing_period_start_offset(self, budget_processing_period_start_offset):
        """
        Sets the budget_processing_period_start_offset of this BudgetSummary.
        The number of days offset from the first day of the month, at which the budget processing period starts. In months that have fewer days than this value, processing will begin on the last day of that month. For example, for a value of 12, processing starts every month on the 12th at midnight.


        :param budget_processing_period_start_offset: The budget_processing_period_start_offset of this BudgetSummary.
        :type: int
        """
        self._budget_processing_period_start_offset = budget_processing_period_start_offset

    @property
    def target_type(self):
        """
        Gets the target_type of this BudgetSummary.
        The type of target on which the budget is applied.

        Allowed values for this property are: "COMPARTMENT", "TAG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The target_type of this BudgetSummary.
        :rtype: str
        """
        return self._target_type

    @target_type.setter
    def target_type(self, target_type):
        """
        Sets the target_type of this BudgetSummary.
        The type of target on which the budget is applied.


        :param target_type: The target_type of this BudgetSummary.
        :type: str
        """
        allowed_values = ["COMPARTMENT", "TAG"]
        if not value_allowed_none_or_none_sentinel(target_type, allowed_values):
            target_type = 'UNKNOWN_ENUM_VALUE'
        self._target_type = target_type

    @property
    def targets(self):
        """
        Gets the targets of this BudgetSummary.
        The list of targets on which the budget is applied.
          If targetType is \"COMPARTMENT\", targets contains list of compartment OCIDs.
          If targetType is \"TAG\", targets contains list of cost tracking tag identifiers in the form of \"{tagNamespace}.{tagKey}.{tagValue}\".


        :return: The targets of this BudgetSummary.
        :rtype: list[str]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """
        Sets the targets of this BudgetSummary.
        The list of targets on which the budget is applied.
          If targetType is \"COMPARTMENT\", targets contains list of compartment OCIDs.
          If targetType is \"TAG\", targets contains list of cost tracking tag identifiers in the form of \"{tagNamespace}.{tagKey}.{tagValue}\".


        :param targets: The targets of this BudgetSummary.
        :type: list[str]
        """
        self._targets = targets

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this BudgetSummary.
        The current state of the budget.

        Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this BudgetSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this BudgetSummary.
        The current state of the budget.


        :param lifecycle_state: The lifecycle_state of this BudgetSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def alert_rule_count(self):
        """
        **[Required]** Gets the alert_rule_count of this BudgetSummary.
        Total number of alert rules in the budget


        :return: The alert_rule_count of this BudgetSummary.
        :rtype: int
        """
        return self._alert_rule_count

    @alert_rule_count.setter
    def alert_rule_count(self, alert_rule_count):
        """
        Sets the alert_rule_count of this BudgetSummary.
        Total number of alert rules in the budget


        :param alert_rule_count: The alert_rule_count of this BudgetSummary.
        :type: int
        """
        self._alert_rule_count = alert_rule_count

    @property
    def version(self):
        """
        Gets the version of this BudgetSummary.
        Version of the budget. Starts from 1 and increments by 1.


        :return: The version of this BudgetSummary.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this BudgetSummary.
        Version of the budget. Starts from 1 and increments by 1.


        :param version: The version of this BudgetSummary.
        :type: int
        """
        self._version = version

    @property
    def actual_spend(self):
        """
        Gets the actual_spend of this BudgetSummary.
        The actual spend in currency for the current budget cycle


        :return: The actual_spend of this BudgetSummary.
        :rtype: float
        """
        return self._actual_spend

    @actual_spend.setter
    def actual_spend(self, actual_spend):
        """
        Sets the actual_spend of this BudgetSummary.
        The actual spend in currency for the current budget cycle


        :param actual_spend: The actual_spend of this BudgetSummary.
        :type: float
        """
        self._actual_spend = actual_spend

    @property
    def forecasted_spend(self):
        """
        Gets the forecasted_spend of this BudgetSummary.
        The forecasted spend in currency by the end of the current budget cycle


        :return: The forecasted_spend of this BudgetSummary.
        :rtype: float
        """
        return self._forecasted_spend

    @forecasted_spend.setter
    def forecasted_spend(self, forecasted_spend):
        """
        Sets the forecasted_spend of this BudgetSummary.
        The forecasted spend in currency by the end of the current budget cycle


        :param forecasted_spend: The forecasted_spend of this BudgetSummary.
        :type: float
        """
        self._forecasted_spend = forecasted_spend

    @property
    def time_spend_computed(self):
        """
        Gets the time_spend_computed of this BudgetSummary.
        Time budget spend was last computed


        :return: The time_spend_computed of this BudgetSummary.
        :rtype: datetime
        """
        return self._time_spend_computed

    @time_spend_computed.setter
    def time_spend_computed(self, time_spend_computed):
        """
        Sets the time_spend_computed of this BudgetSummary.
        Time budget spend was last computed


        :param time_spend_computed: The time_spend_computed of this BudgetSummary.
        :type: datetime
        """
        self._time_spend_computed = time_spend_computed

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this BudgetSummary.
        Time budget was created


        :return: The time_created of this BudgetSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this BudgetSummary.
        Time budget was created


        :param time_created: The time_created of this BudgetSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this BudgetSummary.
        Time budget was updated


        :return: The time_updated of this BudgetSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this BudgetSummary.
        Time budget was updated


        :param time_updated: The time_updated of this BudgetSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this BudgetSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this BudgetSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this BudgetSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this BudgetSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this BudgetSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this BudgetSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this BudgetSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this BudgetSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
